@@ -13,7 +13,7 @@
 # limitations under the License.
 
 """Tools for creating `messages
-<http://www.mongodb.org/display/DOCS/Mongo+Wire+Protocol>`_ to be sent to
+<https://www.mongodb.com/docs/manual/reference/mongodb-wire-protocol/>`_ to be sent to
 MongoDB.
 
 .. note:: This module is for internal use and is generally not needed by
@@ -300,6 +300,9 @@ class _Query(object):
         self._as_command = None
         self.exhaust = exhaust
 
+    def reset(self):
+        self._as_command = None
+
     def namespace(self):
         return "%s.%s" % (self.db, self.coll)
 
@@ -320,7 +323,7 @@ class _Query(object):
         sock_info.validate_session(self.client, self.session)
         return use_find_cmd
 
-    def as_command(self, sock_info):
+    def as_command(self, sock_info, apply_timeout=False):
         """Return a find command document for this query."""
         # We use the command twice: on the wire and for command monitoring.
         # Generate it once, for speed and to avoid repeating side-effects.
@@ -356,11 +359,16 @@ class _Query(object):
         client = self.client
         if client._encrypter and not client._encrypter._bypass_auto_encryption:
             cmd = client._encrypter.encrypt(self.db, cmd, self.codec_options)
+        # Support CSOT
+        if apply_timeout:
+            sock_info.apply_timeout(client, cmd)
         self._as_command = cmd, self.db
         return self._as_command
 
     def get_message(self, read_preference, sock_info, use_cmd=False):
         """Get a query message, possibly setting the secondaryOk bit."""
+        # Use the read_preference decided by _socket_from_server.
+        self.read_preference = read_preference
         if read_preference.mode:
             # Set the secondaryOk bit.
             flags = self.flags | 4
@@ -371,7 +379,7 @@ class _Query(object):
         spec = self.spec
 
         if use_cmd:
-            spec = self.as_command(sock_info)[0]
+            spec = self.as_command(sock_info, apply_timeout=True)[0]
             request_id, msg, size, _ = _op_msg(
                 0,
                 spec,
@@ -457,6 +465,9 @@ class _GetMore(object):
         self.exhaust = exhaust
         self.comment = comment
 
+    def reset(self):
+        self._as_command = None
+
     def namespace(self):
         return "%s.%s" % (self.db, self.coll)
 
@@ -471,7 +482,7 @@ class _GetMore(object):
         sock_info.validate_session(self.client, self.session)
         return use_cmd
 
-    def as_command(self, sock_info):
+    def as_command(self, sock_info, apply_timeout=False):
         """Return a getMore command document for this query."""
         # See _Query.as_command for an explanation of this caching.
         if self._as_command is not None:
@@ -493,6 +504,9 @@ class _GetMore(object):
         client = self.client
         if client._encrypter and not client._encrypter._bypass_auto_encryption:
             cmd = client._encrypter.encrypt(self.db, cmd, self.codec_options)
+        # Support CSOT
+        if apply_timeout:
+            sock_info.apply_timeout(client, cmd=None)
         self._as_command = cmd, self.db
         return self._as_command
 
@@ -503,7 +517,7 @@ class _GetMore(object):
         ctx = sock_info.compression_context
 
         if use_cmd:
-            spec = self.as_command(sock_info)[0]
+            spec = self.as_command(sock_info, apply_timeout=True)[0]
             if self.sock_mgr:
                 flags = _OpMsg.EXHAUST_ALLOWED
             else:
