@@ -25,7 +25,7 @@ import pymongo
 from pymongo.ssl_support import HAS_SNI
 
 try:
-    import dns
+    import dns  # noqa
 
     HAS_DNS = True
 except ImportError:
@@ -79,7 +79,6 @@ class TestAtlasConnect(unittest.TestCase):
     def test_tls_12(self):
         connect(URIS["ATLAS_TLS12"])
 
-    @unittest.skipIf(sys.platform.startswith("java"), "Jython does not support serverless TLS")
     def test_serverless(self):
         connect(URIS["ATLAS_SERVERLESS"])
 
@@ -121,7 +120,7 @@ class TestAtlasConnect(unittest.TestCase):
         duplicates = [names for names in uri_to_names.values() if len(names) > 1]
         self.assertFalse(
             duplicates,
-            "Error: the following env variables have " "duplicate values: %s" % (duplicates,),
+            "Error: the following env variables have duplicate values: %s" % (duplicates,),
         )
 
 
