@@ -20,11 +20,12 @@ import sys
 import tempfile
 import time
 import warnings
+from typing import Any, List
 
 try:
     import simplejson as json
 except ImportError:
-    import json
+    import json  # type: ignore[no-redef]
 
 sys.path[0:0] = [""]
 
@@ -45,11 +46,11 @@ TEST_PATH = os.environ.get(
 
 OUTPUT_FILE = os.environ.get("OUTPUT_FILE")
 
-result_data = []
+result_data: List = []
 
 
 def tearDownModule():
-    output = json.dumps({"results": result_data}, indent=4)
+    output = json.dumps(result_data, indent=4)
     if OUTPUT_FILE:
         with open(OUTPUT_FILE, "w") as opf:
             opf.write(output)
@@ -68,6 +69,11 @@ class Timer(object):
 
 
 class PerformanceTest(object):
+    dataset: Any
+    data_size: Any
+    do_task: Any
+    fail: Any
+
     @classmethod
     def setUpClass(cls):
         client_context.init()
@@ -78,9 +84,21 @@ class PerformanceTest(object):
     def tearDown(self):
         name = self.__class__.__name__
         median = self.percentile(50)
-        result = self.data_size / median
+        bytes_per_sec = self.data_size / median
         print("Running %s. MEDIAN=%s" % (self.__class__.__name__, self.percentile(50)))
-        result_data.append({"name": name, "results": {"1": {"ops_per_sec": result}}})
+        result_data.append(
+            {
+                "info": {
+                    "test_name": name,
+                    "args": {
+                        "threads": 1,
+                    },
+                },
+                "metrics": [
+                    {"name": "bytes_per_sec", "value": bytes_per_sec},
+                ],
+            }
+        )
 
     def before(self):
         pass
@@ -373,6 +391,7 @@ def mp_map(map_func, files):
 
 
 def insert_json_file(filename):
+    assert proc_client is not None
     with open(filename, "r") as data:
         coll = proc_client.perftest.corpus
         coll.insert_many([json.loads(line) for line in data])
@@ -385,11 +404,13 @@ def insert_json_file_with_file_id(filename):
             doc = json.loads(line)
             doc["file"] = filename
             documents.append(doc)
+    assert proc_client is not None
     coll = proc_client.perftest.corpus
     coll.insert_many(documents)
 
 
 def read_json_file(filename):
+    assert proc_client is not None
     coll = proc_client.perftest.corpus
     temp = tempfile.TemporaryFile(mode="w")
     try:
@@ -401,6 +422,7 @@ def read_json_file(filename):
 
 
 def insert_gridfs_file(filename):
+    assert proc_client is not None
     bucket = GridFSBucket(proc_client.perftest)
 
     with open(filename, "rb") as gfile:
@@ -408,6 +430,7 @@ def insert_gridfs_file(filename):
 
 
 def read_gridfs_file(filename):
+    assert proc_client is not None
     bucket = GridFSBucket(proc_client.perftest)
 
     temp = tempfile.TemporaryFile()
