@@ -21,8 +21,7 @@ from test import client_context
 
 from pymongo import MongoClient, common
 from pymongo.errors import AutoReconnect, NetworkTimeout
-from pymongo.hello import Hello
-from pymongo.hello_compat import HelloCompat
+from pymongo.hello import Hello, HelloCompat
 from pymongo.monitor import Monitor
 from pymongo.pool import Pool
 from pymongo.server_description import ServerDescription
@@ -39,7 +38,7 @@ class MockPool(Pool):
         Pool.__init__(self, (client_context.host, client_context.port), *args, **kwargs)
 
     @contextlib.contextmanager
-    def get_socket(self, all_credentials, handler=None):
+    def get_socket(self, handler=None):
         client = self.client
         host_and_port = "%s:%s" % (self.mock_host, self.mock_port)
         if host_and_port in client.mock_down_hosts:
@@ -49,12 +48,33 @@ class MockPool(Pool):
             client.mock_standalones + client.mock_members + client.mock_mongoses
         ), ("bad host: %s" % host_and_port)
 
-        with Pool.get_socket(self, all_credentials, handler) as sock_info:
+        with Pool.get_socket(self, handler) as sock_info:
             sock_info.mock_host = self.mock_host
             sock_info.mock_port = self.mock_port
             yield sock_info
 
 
+class DummyMonitor(object):
+    def __init__(self, server_description, topology, pool, topology_settings):
+        self._server_description = server_description
+        self.opened = False
+
+    def cancel_check(self):
+        pass
+
+    def join(self):
+        pass
+
+    def open(self):
+        self.opened = True
+
+    def request_check(self):
+        pass
+
+    def close(self):
+        self.opened = False
+
+
 class MockMonitor(Monitor):
     def __init__(self, client, server_description, topology, pool, topology_settings):
         # MockMonitor gets a 'client' arg, regular monitors don't. Weakref it
@@ -99,7 +119,10 @@ class MockClient(MongoClient):
         # Hosts that should be considered an arbiter.
         self.mock_arbiters = arbiters[:] if arbiters else []
 
-        self.mock_hello_hosts = hello_hosts or members[:]
+        if hello_hosts is not None:
+            self.mock_hello_hosts = hello_hosts
+        else:
+            self.mock_hello_hosts = members[:]
 
         self.mock_mongoses = mongoses[:]
 
@@ -164,13 +187,13 @@ class MockClient(MongoClient):
                 "maxWriteBatchSize": max_write_batch_size,
             }
         elif host in self.mock_members:
-            is_writable_primary = host == self.mock_primary
+            primary = host == self.mock_primary
 
             # Simulate a replica set member.
             response = {
                 "ok": 1,
-                HelloCompat.LEGACY_CMD: is_writable_primary,
-                "secondary": not is_writable_primary,
+                HelloCompat.LEGACY_CMD: primary,
+                "secondary": not primary,
                 "setName": "rs",
                 "hosts": self.mock_hello_hosts,
                 "minWireVersion": min_wire_version,
