@@ -21,7 +21,7 @@ import threading
 sys.path[0:0] = [""]
 
 from test import IntegrationTest, client_context, unittest
-from test.utils import rs_client
+from test.utils import rs_client, wait_until
 
 import pymongo
 from pymongo.errors import ConnectionFailure, OperationFailure
@@ -945,9 +945,7 @@ class TestTransactionExamples(IntegrationTest):
                     except (ConnectionFailure, OperationFailure) as exc:
                         # Can retry commit
                         if exc.has_error_label("UnknownTransactionCommitResult"):
-                            print(
-                                "UnknownTransactionCommitResult, retrying " "commit operation ..."
-                            )
+                            print("UnknownTransactionCommitResult, retrying commit operation ...")
                             continue
                         else:
                             print("Error during commit ...")
@@ -959,6 +957,7 @@ class TestTransactionExamples(IntegrationTest):
             update_employee_info(session)
 
         employee = employees.find_one({"employee": 3})
+        assert employee is not None
         self.assertIsNotNone(employee)
         self.assertEqual(employee["status"], "Inactive")
 
@@ -969,11 +968,11 @@ class TestTransactionExamples(IntegrationTest):
                     txn_func(session)  # performs transaction
                     break
                 except (ConnectionFailure, OperationFailure) as exc:
-                    print("Transaction aborted. Caught exception during " "transaction.")
+                    print("Transaction aborted. Caught exception during transaction.")
 
                     # If transient error, retry the whole transaction
                     if exc.has_error_label("TransientTransactionError"):
-                        print("TransientTransactionError, retrying" "transaction ...")
+                        print("TransientTransactionError, retrying transaction ...")
                         continue
                     else:
                         raise
@@ -984,6 +983,7 @@ class TestTransactionExamples(IntegrationTest):
             run_transaction_with_retry(update_employee_info, session)
 
         employee = employees.find_one({"employee": 3})
+        assert employee is not None
         self.assertIsNotNone(employee)
         self.assertEqual(employee["status"], "Inactive")
 
@@ -998,7 +998,7 @@ class TestTransactionExamples(IntegrationTest):
                 except (ConnectionFailure, OperationFailure) as exc:
                     # Can retry commit
                     if exc.has_error_label("UnknownTransactionCommitResult"):
-                        print("UnknownTransactionCommitResult, retrying " "commit operation ...")
+                        print("UnknownTransactionCommitResult, retrying commit operation ...")
                         continue
                     else:
                         print("Error during commit ...")
@@ -1020,6 +1020,7 @@ class TestTransactionExamples(IntegrationTest):
             run_transaction_with_retry(_insert_employee_retry_commit, session)
 
         employee = employees.find_one({"employee": 4})
+        assert employee is not None
         self.assertIsNotNone(employee)
         self.assertEqual(employee["status"], "Active")
 
@@ -1033,7 +1034,7 @@ class TestTransactionExamples(IntegrationTest):
                 except (ConnectionFailure, OperationFailure) as exc:
                     # If transient error, retry the whole transaction
                     if exc.has_error_label("TransientTransactionError"):
-                        print("TransientTransactionError, retrying " "transaction ...")
+                        print("TransientTransactionError, retrying transaction ...")
                         continue
                     else:
                         raise
@@ -1048,7 +1049,7 @@ class TestTransactionExamples(IntegrationTest):
                 except (ConnectionFailure, OperationFailure) as exc:
                     # Can retry commit
                     if exc.has_error_label("UnknownTransactionCommitResult"):
-                        print("UnknownTransactionCommitResult, retrying " "commit operation ...")
+                        print("UnknownTransactionCommitResult, retrying commit operation ...")
                         continue
                     else:
                         print("Error during commit ...")
@@ -1085,6 +1086,7 @@ class TestTransactionExamples(IntegrationTest):
         # End Transactions Retry Example 3
 
         employee = employees.find_one({"employee": 3})
+        assert employee is not None
         self.assertIsNotNone(employee)
         self.assertEqual(employee["status"], "Inactive")
 
@@ -1155,6 +1157,9 @@ class TestCausalConsistencyExamples(IntegrationTest):
             )
         # End Causal Consistency Example 1
 
+        assert s1.cluster_time is not None
+        assert s1.operation_time is not None
+
         # Start Causal Consistency Example 2
         with client.start_session(causal_consistency=True) as s2:
             s2.advance_cluster_time(s1.cluster_time)
@@ -1196,6 +1201,7 @@ class TestVersionedApiExamples(IntegrationTest):
         client = MongoClient(uri, server_api=ServerApi("1", deprecation_errors=True))
         # End Versioned API Example 4
 
+    @unittest.skip("PYTHON-3167 count has been added to API version 1")
     @client_context.require_version_min(4, 7)
     def test_versioned_api_migration(self):
         # SERVER-58785
@@ -1275,7 +1281,7 @@ class TestVersionedApiExamples(IntegrationTest):
 
         with self.assertRaisesRegex(
             OperationFailure,
-            "Provided apiStrict:true, but the command " "count is not in API Version 1",
+            "Provided apiStrict:true, but the command count is not in API Version 1",
         ):
             client.db.command("count", "sales", query={})
         # Start Versioned API Example 6
@@ -1291,5 +1297,90 @@ class TestVersionedApiExamples(IntegrationTest):
         # End Versioned API Example 8
 
 
+class TestSnapshotQueryExamples(IntegrationTest):
+    @client_context.require_version_min(5, 0)
+    def test_snapshot_query(self):
+        client = self.client
+
+        if not client_context.is_topology_type(["replicaset", "sharded"]):
+            self.skipTest("Must be a sharded or replicaset")
+
+        self.addCleanup(client.drop_database, "pets")
+        db = client.pets
+        db.drop_collection("cats")
+        db.drop_collection("dogs")
+        db.cats.insert_one({"name": "Whiskers", "color": "white", "age": 10, "adoptable": True})
+        db.dogs.insert_one({"name": "Pebbles", "color": "Brown", "age": 10, "adoptable": True})
+        wait_until(lambda: self.check_for_snapshot(db.cats), "success")
+        wait_until(lambda: self.check_for_snapshot(db.dogs), "success")
+
+        # Start Snapshot Query Example 1
+
+        db = client.pets
+        with client.start_session(snapshot=True) as s:
+            adoptablePetsCount = db.cats.aggregate(
+                [{"$match": {"adoptable": True}}, {"$count": "adoptableCatsCount"}], session=s
+            ).next()["adoptableCatsCount"]
+
+            adoptablePetsCount += db.dogs.aggregate(
+                [{"$match": {"adoptable": True}}, {"$count": "adoptableDogsCount"}], session=s
+            ).next()["adoptableDogsCount"]
+
+        print(adoptablePetsCount)
+
+        # End Snapshot Query Example 1
+        db = client.retail
+        self.addCleanup(client.drop_database, "retail")
+        db.drop_collection("sales")
+
+        saleDate = datetime.datetime.now()
+        db.sales.insert_one({"shoeType": "boot", "price": 30, "saleDate": saleDate})
+        wait_until(lambda: self.check_for_snapshot(db.sales), "success")
+
+        # Start Snapshot Query Example 2
+        db = client.retail
+        with client.start_session(snapshot=True) as s:
+            total = db.sales.aggregate(
+                [
+                    {
+                        "$match": {
+                            "$expr": {
+                                "$gt": [
+                                    "$saleDate",
+                                    {
+                                        "$dateSubtract": {
+                                            "startDate": "$$NOW",
+                                            "unit": "day",
+                                            "amount": 1,
+                                        }
+                                    },
+                                ]
+                            }
+                        }
+                    },
+                    {"$count": "totalDailySales"},
+                ],
+                session=s,
+            ).next()["totalDailySales"]
+
+        # End Snapshot Query Example 2
+
+    def check_for_snapshot(self, collection):
+        """Wait for snapshot reads to become available to prevent this error:
+        [246:SnapshotUnavailable]: Unable to read from a snapshot due to pending collection catalog changes; please retry the operation. Snapshot timestamp is Timestamp(1646666892, 4). Collection minimum is Timestamp(1646666892, 5) (on localhost:27017, modern retry, attempt 1)
+        From https://github.com/mongodb/mongo-ruby-driver/commit/7c4117b58e3d12e237f7536f7521e18fc15f79ac
+        """
+        with self.client.start_session(snapshot=True) as s:
+            try:
+                with collection.aggregate([], session=s):
+                    pass
+                return True
+            except OperationFailure as e:
+                # Retry them as the server demands...
+                if e.code == 246:  # SnapshotUnavailable
+                    return False
+                raise
+
+
 if __name__ == "__main__":
     unittest.main()
