@@ -151,12 +151,14 @@ class TestReadWriteConcernSpec(IntegrationTest):
                 f()
             if expected == BulkWriteError:
                 bulk_result = cm.exception.details
+                assert bulk_result is not None
                 wc_errors = bulk_result["writeConcernErrors"]
                 self.assertTrue(wc_errors)
 
     @client_context.require_replica_set
     def test_raise_write_concern_error(self):
         self.addCleanup(client_context.client.drop_database, "pymongo_test")
+        assert client_context.w is not None
         self.assertWriteOpsRaise(
             WriteConcern(w=client_context.w + 1, wtimeout=1), WriteConcernError
         )
@@ -217,6 +219,7 @@ class TestReadWriteConcernSpec(IntegrationTest):
             db.test.insert_one({"x": 1})
         self.assertEqual(ctx.exception.code, 121)
         self.assertIsNotNone(ctx.exception.details)
+        assert ctx.exception.details is not None
         self.assertIsNotNone(ctx.exception.details.get("errInfo"))
         for event in listener.results["succeeded"]:
             if event.command_name == "insert":
@@ -272,15 +275,15 @@ def create_document_test(test_case):
             if not valid:
                 self.assertRaises((ConfigurationError, ValueError), WriteConcern, **normalized)
             else:
-                concern = WriteConcern(**normalized)
-                self.assertEqual(concern.document, test_case["writeConcernDocument"])
-                self.assertEqual(concern.acknowledged, test_case["isAcknowledged"])
-                self.assertEqual(concern.is_server_default, test_case["isServerDefault"])
+                write_concern = WriteConcern(**normalized)
+                self.assertEqual(write_concern.document, test_case["writeConcernDocument"])
+                self.assertEqual(write_concern.acknowledged, test_case["isAcknowledged"])
+                self.assertEqual(write_concern.is_server_default, test_case["isServerDefault"])
         if "readConcern" in test_case:
             # Any string for 'level' is equaly valid
-            concern = ReadConcern(**test_case["readConcern"])
-            self.assertEqual(concern.document, test_case["readConcernDocument"])
-            self.assertEqual(not bool(concern.level), test_case["isServerDefault"])
+            read_concern = ReadConcern(**test_case["readConcern"])
+            self.assertEqual(read_concern.document, test_case["readConcernDocument"])
+            self.assertEqual(not bool(read_concern.level), test_case["isServerDefault"])
 
     return run_test
 
